//
//  DependencyFactory.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

//Factory for injecting dependencies to mayor viewcomponents
//such as login and tabViewComponent
//This is used from rootViewComponent

protocol HasAuthRequestManager {
    var authRequestManager: FirebaseAuthManager & FBObserverManager { get }
}
protocol HasFirestoreManager {
    var firestoreManager: FirebaseFirestoreManager { get }
}
protocol HasLocationManager {
    var locationManager: LocationManager { get }
}
protocol HasImageCacheManager {
    var imageCacheManager: ImageCacheManager { get }
}
protocol HasFirebaseImageUpload {
    var firebaseImageUpload: FirebaseImageUploadService { get }
}

struct Dependencies: HasAuthRequestManager, HasFirestoreManager, HasLocationManager, HasImageCacheManager, HasFirebaseImageUpload {
    let authRequestManager: FirebaseAuthManager & FBObserverManager = FirebaseAuthServices()
    let firestoreManager: FirebaseFirestoreManager = FirebaseFirestoreServices()
    let locationManager: LocationManager = CoreLocationServices()
    let imageCacheManager: ImageCacheManager = ImageLoadingCachingService()
    let firebaseImageUpload: FirebaseImageUploadService = FirebaseImageUploadService()
}


