//
//  AddPlaceInteractor.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import Foundation

//Interactor protocol is an abstraction of the interactor
//This will be used by the viewController
protocol AddPlaceInteractorProtocol{
    func savePlace(request: AddPlaceBusinessModel.SavePlace.Request)
    func viewDidLoad()
    func getUserLocation()
}

//Interactor is in charge of getting data from worker
//will pass data to presenter
class AddPlaceInteractor: AddPlaceInteractorProtocol {

    let worker: AddPlaceWorkerProtocol
    let presenter: AddPlacePresenterProtocol
    
    init(worker: AddPlaceWorkerProtocol, presenter: AddPlacePresenterProtocol){
        self.worker = worker
        self.presenter = presenter
    }
    
    func viewDidLoad() {
        presenter.presentSetupView()
    }
    
    func getUserLocation() {
        worker.getUserLocation(success: { [weak self] location in
            self?.presenter.presentUserLocation(location: location)
        }, failure: { error in
            //Some error
        })
    }
    
    func savePlace(request: AddPlaceBusinessModel.SavePlace.Request) {
        presenter.presentLoading()
        worker.savePlaceImage(path: request.image!, name: request.name){ [weak self] url, error in
            if error != nil {
                //tell presenter to show error
                return
            }
            if let url = url {
                self?.worker.savePlace(
                    name: request.name,
                    description: request.description,
                    tags: request.tags,
                    image: url){ didSave in
                    // tell presenter to show dialog
                    if(didSave){
                        // send to presenter success message
                        let text = "Este Spot se ha guardado exitosamente"
                        self?.presenter.removeLoading()
                        self?.presenter.presentResponse(text: text)
                    }else{
                        // send to presenter error message
                        let text = "Lo sentimos ha ocurrido un error. Intente nuevamente."
                        self?.presenter.removeLoading()
                        self?.presenter.presentResponse(text: text)
                    }
                    
                }
            }
        }

    }
    
    
}
