//
//  AddPlacePresenter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import UIKit

// Presenter abstraction
protocol AddPlacePresenterProtocol{
    func presentRouteBack()
    func presentLoading()
    func removeLoading()
    func presentSetupView()
    func presentUserLocation(location: Location)
    func presentResponse(text: String)
}

// Presenter for login. Will tell the view what to show.
class AddPlacePresenter: AddPlacePresenterProtocol {
    
    weak var viewController: (
        AddPlaceViewRouteProtocol &
        AddPlaceViewLoadingProtocol
    )?
    
    func presentRouteBack() {
        viewController?.displayRouteBack()
    }
    
    func presentLoading() {
        viewController?.displayLoading()
    }
    
    func removeLoading() {
        viewController?.hideLoading()
    }
    
    func presentResponse(text: String){
        viewController?.displayResultAlert(text: text)
    }
    
    func presentUserLocation(location: Location) {
        viewController?.displayLocationInMap(location: location)
    }
    
    func presentSetupView() {
        viewController?.displaySetupView(
            viewModel: .init(
                save: .init(cornerRadius: 5, borderWidth: 1, borderColor: UIColor.systemGreen.cgColor),
                validator: { name, desc, tags, imgUrl in
                    let nameVal = name ?? ""
                    let descVal = desc ?? ""
                    let tagsVal = tags ?? ""
                    let imgUrlVal = imgUrl
                    
                    var isValid = true
                    var errorMessage = ""
                    if nameVal.isEmpty{
                        errorMessage = "Introduzca el nombre del lugar"
                        isValid = false
                    }else if descVal.isEmpty{
                        errorMessage = "Introduzca una descripcion"
                        isValid = false
                    }else if tagsVal.isEmpty{
                        errorMessage = "Introduzca los tags"
                        isValid = false
                    }else if imgUrlVal == nil {
                        errorMessage = "Agregue una foto del lugar"
                        isValid = false
                    }
                    return .init(
                        errorMessage: errorMessage,
                        isValid: isValid,
                        nameValue: nameVal,
                        descriptionValue: descVal,
                        tagsValue: tagsVal,
                        imageValue: imgUrlVal)
                })
        )
    }
    
}
