//
//  DetailInteractor.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import Foundation

protocol DetailInteractorProtocol {
    func loadData()
    func unloadData()
    func viewDidLoad()
    func updateAttendees(willAssist: Bool)
    func addEventToUser(reques: DetailBusinessModel.AddEvent.Request)
}
protocol DetailDataStore: AnyObject {
    var place: Place? { get set }
    var activity: Activity? { get set }
    var placeForEvent: Place? { get set }
}
class DetailInteractor: DetailInteractorProtocol, DetailDataStore {

    var place: Place?
    var activity: Activity?
    var placeForEvent: Place?
    
    let presenter: DetailPresenterProtocol
    let worker: DetailWorkerProtocol

    init(presenter: DetailPresenterProtocol, worker: DetailWorkerProtocol){
        self.presenter = presenter
        self.worker = worker
    }
    //Will display the data passed from the view.
    func loadData() {
        if let placeValue = place {
            presenter.presentPlaceData(response: .init(place: placeValue))
            placeForEvent = placeValue
        }
        if let activityValue = activity {
            presenter.presentActivityData(response: .init(activity: activityValue))
            let userId = worker.getUserID()
            let hasId = activityValue.attendeesIDs.first(where: {$0 == userId })
            if hasId != nil {
                presenter.changeAssistButton(userIsAssisting: true)
            }else{
                presenter.changeAssistButton(userIsAssisting: false)
            }
        }
    }
    //Will set the datastore to nil
    func unloadData(){
        place = nil
        activity = nil
    }
    //Will set the view styles and viewmodels
    func viewDidLoad(){
        presenter.presentSetupView()
    }
    
    //Updates the attendees count
    func updateAttendees(willAssist: Bool) {
        let pos = Location(latitude: activity!.lat, longitude: activity!.lng)
        var count = activity!.attendees
        if(willAssist){
             count = count + 1
        }else{
            count = count - 1
        }
        worker.updateAttendeesCount(
            position: pos,
            attendeesIds: activity!.attendeesIDs,
            count: count,
            uid: activity!.uid){ didUpdate in
            print("did update activity: \(didUpdate)")
        }
    }
    
    //Will save the evento to the user
    //When its done will tell the presenter to show a dialog
    func addEventToUser(reques: DetailBusinessModel.AddEvent.Request) {
        presenter.presentLoading()
        let pos = Location(latitude: activity!.lat, longitude: activity!.lng)
        worker.addToUserEvents(
            position: pos,
            activityUid: activity!.uid,
            date: activity!.dateTime,
            isCreator: reques.isCreator,
            isGoing: reques.isGoing,
            name: activity!.name,
            whereName: activity!.placeName ){ [weak self] didSave in
            self?.presenter.presentResponse(text: "Se ha guardado este evento exitosamente. Para editar tu asistencia dirigete a la pestaña de Mis Eventos")
        }
    }
    
    
    
}
