//
//  DetailPresenter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import UIKit

protocol DetailPresenterProtocol {
    func presentPlaceData(response: DetailBusinessModel.LoadData.PlaceResponse)
    func presentActivityData(response: DetailBusinessModel.LoadData.ActivityResponse)
    func presentSetupView()
    func presentLoading()
    func removeLoading()
    func changeAssistButton(userIsAssisting: Bool)
    func presentResponse(text: String)
}

class DetailPresenter: DetailPresenterProtocol {
    
    weak var viewController: (DetailViewControllerProtocol & DetailViewLoadingProtocol)?
    
    let imageCache: ImageCacheManager
    init(imageCache: ImageCacheManager){
        self.imageCache = imageCache
    }
    
    func presentPlaceData(response: DetailBusinessModel.LoadData.PlaceResponse) {
        let data = response.place
        viewController?.displayData(
            viewModel: .init(
                name: data.name,
                description: data.description,
                lat: data.lat,
                lng: data.lng,
                date: nil,
                attendees: nil,
                placeName: nil,
                isPlace: true,
                loadImage: { [weak self] imageView in
                    self?.imageCache.getImage(data.image){ image in
                        imageView.image = image
                    }
                }
            )
        )
    }
    
    func presentActivityData(response: DetailBusinessModel.LoadData.ActivityResponse) {
        let data = response.activity
        viewController?.displayData(
            viewModel: .init(
                name: data.name,
                description: data.description,
                lat: data.lat,
                lng: data.lng,
                date: data.dateTime,
                attendees: data.attendees,
                placeName: data.placeName,
                isPlace: false,
                loadImage: { imageView in
                    //nothing
                }
            )
        )
    }
    
    func presentSetupView(){
        viewController?.displaySetupView(
            viewModel: .init(
                greenButton: .init(cornerRadius: 5, borderWidth: 1, borderColor: UIColor.systemGreen.cgColor),
                grayButton: .init(cornerRadius: 5, borderWidth: 1, borderColor: UIColor.systemGray4.cgColor)
            )
        )
    }
    
    func presentResponse(text: String) {
        viewController?.displayResultAlert(text: text)
    }
    
    func presentLoading() {
        viewController?.displayLoading()
    }
    
    func removeLoading() {
        viewController?.hideLoading()
    }
    
    //To change hide assist button if user is going to the event
    func changeAssistButton(userIsAssisting: Bool) {
        viewController?.displayChangeAssistButton(userIsAssisting: userIsAssisting)
    }
    
}


