//
//  DetailRouter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import UIKit

protocol DetailRouterProtocol {
    var dataStore: DetailDataStore? { get set }
    func routeBack()
    func routeNewEvent()
}

class DetailRouter: DetailRouterProtocol {

    weak var dataStore: DetailDataStore?
    
    weak var viewController: UIViewController?

    static func assemble(
        firestore: FirebaseFirestoreManager,
        auth: FirebaseAuthManager,
        imageCache: ImageCacheManager,
        location: LocationManager) -> DetailViewController {
        let router = DetailRouter()
        let presenter = DetailPresenter(imageCache: imageCache)
        let worker = DetailWorker(
            firestore: firestore,
            auth: auth,
            location: location)
        let interactor = DetailInteractor(presenter: presenter, worker: worker)
        let view = DetailViewController(interactor: interactor, router: router)
        presenter.viewController = view
        router.viewController = view
        router.dataStore = interactor
        return view
    }
    
    func routeBack() {
        let navigation = viewController?.navigationController
        navigation?.dismiss(animated: false)
    }

    func routeNewEvent() {
        let navigation = viewController?.navigationController
        let destinationVC = NewEventRouter.assemble(
            firestore: FirebaseFirestoreServices(),
            auth: FirebaseAuthServices(),
            location: CoreLocationServices())
        var destinationDS = destinationVC.router.dataStore!
        destinationVC.hidesBottomBarWhenPushed = true
        passDataToDetail(source: dataStore!, destination: &destinationDS)
        navigation?.pushViewController(destinationVC, animated: true)
    }
    
    func passDataToDetail(source: DetailDataStore, destination: inout NewEventDataStore){
        destination.place = source.placeForEvent
    }
    
}
