//
//  DetailWorker.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

//Abstraction of worker
//The worker will request data to the apis
protocol DetailWorkerProtocol {
    func updateAttendeesCount(
        position: Location,
        attendeesIds: [String],
        count: Int,
        uid: String,
        completion: @escaping (_ didUpdate: Bool)->Void)
    func addToUserEvents(
        position: Location,
        activityUid: String,
        date: String,
        isCreator: Bool,
        isGoing: Bool,
        name: String,
        whereName: String,
        completion: @escaping (_ didSave: Bool)->Void)
    func getUserID()->String
}

//Detail worker
//This class for the detail will update attendees count
//This class will also save or remove an event into the user events collection
class DetailWorker: DetailWorkerProtocol {
    
    let firestore: FirebaseFirestoreManager
    let auth: FirebaseAuthManager
    let location: LocationManager
    
    init(firestore: FirebaseFirestoreManager, auth: FirebaseAuthManager, location: LocationManager){
        self.firestore = firestore
        self.auth = auth
        self.location = location
    }
    
    //Will update the number in the activity
    //needs the city to do it
    func updateAttendeesCount(
        position: Location,
        attendeesIds: [String],
        count: Int,
        uid: String,
        completion: @escaping (Bool) -> Void) {
        location.getCityFromLocation(location: position){ [weak self] city in
            if let city = city {
                let userUID = (self?.auth.getUser()!.uid)! as String
                var newArray = attendeesIds
                newArray.append(userUID)
                let d:[String : Any] = [
                    "attendees": count,
                    "attendeesIDs": newArray
                ]
                self?.firestore.updateDeeper(
                    mainCollection: "Cities",
                    mainDocument: city,
                    secondaryCollection: "Activities",
                    secondaryDocument: uid,
                    data: d){ didUpdate in
                    completion(true)
                }
            }
            completion(false)
        }
    }
    
    //Will add the event related to the activity to the user collection
    func addToUserEvents(
        position: Location,
        activityUid: String,
        date: String,
        isCreator: Bool,
        isGoing: Bool,
        name: String,
        whereName: String,
        completion: @escaping (_ didSave: Bool)->Void){
        
        let userUID = auth.getUser()!.uid as String
        location.getCityFromLocation(location: position){ [weak self] city in
            if let city = city {
                let d:[String:Any] = [
                    "activityUid": activityUid,
                    "date": date,
                    "isCreator": false,
                    "isGoing": true,
                    "name": name,
                    "where": whereName,
                    "city": city
                ]
                
                self?.firestore.postDataDeeperWithUID(
                    mainCollection: "Users",
                    mainDocument: userUID,
                    secondaryCollection: "Events",
                    documentUID: activityUid,
                    data: d){ didSave in
                    completion(true)
                }
            }
            completion(false)
        }
    }

    func getUserID() -> String {
        return auth.getUser()!.uid as String
    }
    
}
