//
//  HomeRouter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

protocol HomeRouterProtocol {
    var dataStore: HomeDataStore? { get set }
    func routeToDetail()
    func routeToAddPlace()
}

class HomeRouter: HomeRouterProtocol {

    weak var dataStore: HomeDataStore?
    weak var viewController: UIViewController?

    static func assemble(dependencies:
                            HasAuthRequestManager &
                            HasFirestoreManager &
                            HasLocationManager &
                            HasImageCacheManager) -> UIViewController {
        let router = HomeRouter()
        let worker = HomeWorker(firestore: dependencies.firestoreManager, location: dependencies.locationManager)
        let presenter = HomePresenter(imageCache: dependencies.imageCacheManager)
        let interactor = HomeInteractor(worker: worker, presenter: presenter)
        let view = HomeViewController(interactor: interactor, router: router)
        presenter.viewController = view
        router.viewController = view
        router.dataStore = interactor
        let nav = UINavigationController(rootViewController: view)
        return nav
    }
    
    func routeToDetail() {
        let navigation = viewController?.navigationController
        let destinationVC = DetailRouter.assemble(
            firestore: FirebaseFirestoreServices(),
            auth: FirebaseAuthServices(),
            imageCache: ImageLoadingCachingService(),
            location: CoreLocationServices())
        var destinationDS = destinationVC.router.dataStore!
        destinationVC.hidesBottomBarWhenPushed = true
        passDataToDetail(source: dataStore!, destination: &destinationDS)
        navigation?.pushViewController(destinationVC, animated: true)
    }
    
    
    func passDataToDetail(source: HomeDataStore, destination: inout DetailDataStore){
        destination.activity = source.selectedActivity
        destination.place = source.selectedPlace
    }
    
    
    func routeToAddPlace(){
        let navigation = viewController?.navigationController
        let destinationVC = AddPlaceRouter.assemble(
            firestore: FirebaseFirestoreServices(),
            location: CoreLocationServices(),
            firebaseImageUpload: FirebaseImageUploadService())
        destinationVC.hidesBottomBarWhenPushed = true
        navigation?.pushViewController(destinationVC, animated: true)
    }

}
