//
//  InterestsInteractor.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

protocol InterestsInteractorProtocol {
    func viewDidLoad()
    func saveInterests(request: InterestsBusinessModel.SaveInterests.Request)
}
class InterestsInteractor: InterestsInteractorProtocol {
    
    let worker: InterestsWorkerProtocol
    let presenter: InterestsPresenterProtocol
    
    init(worker: InterestsWorkerProtocol, presenter: InterestsPresenterProtocol){
        self.worker = worker
        self.presenter = presenter
    }
    
    func viewDidLoad() {
        presenter.presentSetupView()
    }
    
    func saveInterests(request: InterestsBusinessModel.SaveInterests.Request) {
        presenter.presentLoading()
        worker.saveInterests(interests: request.interests){ [weak self] success in
            if(success){
                self?.presenter.removeLoading()
                self?.presenter.presentRouteToHome()
            }else{
                self?.presenter.removeLoading()
                self?.presenter.presentError(text: "Hubo un problema guardando sus preferencias")
            }
        }
    }
    
    
    
}
