//
//  InterestsPresenter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

protocol InterestsPresenterProtocol {
    func presentRouteToHome()
    func presentLoading()
    func removeLoading()
    func presentSetupView()
    func presentError(text: String)
}

class InterestsPresenter: InterestsPresenterProtocol {
    
    weak var viewController: (
        InterestsViewControllerRouteProtocol & InterestsViewControllerLoadingProtocol
    )?
    
    func presentRouteToHome() {
        viewController?.displayRouteToHome()
    }
    
    func presentLoading() {
        viewController?.displayLoading()
    }
    
    func removeLoading() {
        viewController?.hideLoading()
    }
    
    func presentError(text: String){
        viewController?.displayError(text: text)
    }
    
    func presentSetupView() {
        viewController?.displaySetupView(
            viewModel: .init(
                continueBtn: .init(cornerRadius: 5, borderWidth: 1, borderColor: UIColor.systemGreen.cgColor),
                validator: { interests in
                    let interestsValue = interests ?? ""
                    var isValid = true
                    var errorMessage = ""
                    if interestsValue.isEmpty{
                        errorMessage = "Introduzca sus intereses"
                        isValid = false
                    }
                    return .init(errorMessage: errorMessage, isValid: isValid, interestsValue: interestsValue)
                })
        )
    }
    
 
    
}
