//
//  InterestsViewController.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

//Protocol to route back to root
protocol InterestsViewControllerRouteProtocol: AnyObject {
    func displayRouteToHome()
    func displaySetupView(viewModel: InterestsBusinessModel.SetupView.ViewModel)
    func displayError(text: String)
}

//Protocol to display loading
protocol InterestsViewControllerLoadingProtocol: AnyObject {
    func displayLoading()
    func hideLoading()
}

class InterestsViewController: UIViewController, InterestsViewControllerRouteProtocol, InterestsViewControllerLoadingProtocol {
    
    @IBOutlet weak var continueBtn: UIButton!
    @IBOutlet weak var interestsInput: UITextView!
    @IBOutlet weak var validationText: UILabel!
    @IBOutlet weak var loader: UIActivityIndicatorView!
    
    var viewModel: InterestsBusinessModel.SetupView.ViewModel?
    
    let interactor: InterestsInteractorProtocol
    let router: InterestsRouterProtocol
    
    init(interactor: InterestsInteractorProtocol, router: InterestsRouterProtocol) {
        self.interactor = interactor
        self.router = router
        let bundle = Bundle(for: InterestsViewController.self)
        super.init(nibName: "\(InterestsViewController.self)", bundle: bundle)
    }
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        interactor.viewDidLoad()
    }
    
    @IBAction func continueClick(_ sender: Any) {
        guard let validator = viewModel?.validator(interestsInput.text) else {
            return
        }
        validationText.isHidden = validator.isValid
        validationText.text = validator.errorMessage
        if validator.isValid {
            interactor.saveInterests(
                request: InterestsBusinessModel.SaveInterests.Request(
                    interests: validator.interestsValue
                )
            )
        }
    }
    
    func displayRouteToHome() {
        router.routeToHome()
    }
    
    func displayError(text: String) {
        let alert = UIAlertController(title: "Aviso", message: text, preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "Entendido", style: .default, handler: nil))
        self.present(alert, animated: true, completion: nil)
    }
    
    func displayLoading() {
        loader.isHidden = false
        validationText.isHidden = true
        continueBtn.isHidden = true
    }
    
    func hideLoading() {
        loader.isHidden = true
        continueBtn.isHidden = false
    }
    
    func displaySetupView(viewModel: InterestsBusinessModel.SetupView.ViewModel) {
        self.viewModel = viewModel
        continueBtn.layer.cornerRadius = viewModel.continueBtn.cornerRadius
        continueBtn.layer.borderWidth = viewModel.continueBtn.borderWidth
        continueBtn.layer.borderColor = viewModel.continueBtn.borderColor
        self.navigationController?.setNavigationBarHidden(true, animated: false)
        //Looks for single or multiple taps.
        let tap = UITapGestureRecognizer(
            target: self,
            action: #selector(UIInputViewController.dismissKeyboard)
        )
        view.addGestureRecognizer(tap)
    }
    
    
}

