//
//  LoginInteractor.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

// Interactor abstraction
protocol LoginInteractorProtocol {
    func viewDidLoad()
    func login(request: LoginBusinessModel.Login.Request)
}

// Class that sends transformed data to the presenter
class LoginInteractor: LoginInteractorProtocol {
    
    let worker: LoginWorkerProtocol
    let presenter: LoginPresenterProtocol
    
    init(worker: LoginWorkerProtocol, presenter: LoginPresenterProtocol) {
        self.worker = worker
        self.presenter = presenter
    }
    
    func viewDidLoad() {
        presenter.presentSetupView()
    }
    
    func login(request: LoginBusinessModel.Login.Request) {
        presenter.presentLoading()
        self.worker.login(request: request) { [weak self] sessionResponse in
            print("LOGIN INTERACTOR RESPONSE \(sessionResponse.username)")
            self?.presenter.removeLoading()
            self?.presenter.presentRouteToHome()
        } failure: { [weak self] error in
            print("LOGIN INTERACTOR ERROR \(error)")
            self?.presenter.removeLoading()
            self?.presenter.presentError(text: "Error en el inicio de sesión. Por favor verifique su usuario y contraseña.")
        }

    }
    
}
