//
//  LoginPresenter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

// Presenter abstraction
protocol LoginPresenterProtocol{
    func presentRouteToHome()
    func presentLoading()
    func removeLoading()
    func presentSetupView()
    func presentError(text: String)
}

// Presenter for login. Will tell the view what to show.
class LoginPresenter: LoginPresenterProtocol {
    
    weak var viewController: (
        LoginViewControllerLoadingProtocol &
        LoginViewControllerRouteProtocol
    )?
    
    func presentRouteToHome() {
        viewController?.displayRouteToRoot()
    }
    
    func presentLoading() {
        viewController?.displayLoading()
    }
    
    func removeLoading() {
        viewController?.hideLoading()
    }
    
    func presentError(text: String){
        viewController?.displayError(text: text)
    }
    
    func presentSetupView() {
        viewController?.displaySetupView(
            viewModel: .init(
                signIn: .init(cornerRadius: 5, borderWidth: 1, borderColor: UIColor.systemGreen.cgColor),
                validator: { username, password in
                    let usernameValue = username ?? ""
                    let passwordValue = password ?? ""
                    var isValid = true
                    var errorMessage = ""
                    if usernameValue.isEmpty{
                        errorMessage = "Introduzca su usuario"
                        isValid = false
                    }else if passwordValue.isEmpty{
                        errorMessage = "Introduzca su contraseña"
                        isValid = false
                    }
                    return .init(errorMessage: errorMessage, isValid: isValid, usernameValue: usernameValue, passwordValue: passwordValue)
                },
                username: .init(placeholder: "Correo electrónico"),
                password: .init(placeholder: "Contraseña"))
        )
    }
    
}
