//
//  LoginRouter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

//Router abstraction
protocol LoginRouterProtocol {
    func routeToRoot()
    func routeToPassReset()
    func routeToRegister()
}

class LoginRouter: LoginRouterProtocol {

    weak var viewController: UIViewController?

    static func assemble(dependencies: HasAuthRequestManager & HasFirestoreManager) -> UIViewController {
        let router = LoginRouter()
        let worker = LoginWorker(authRequestManager: dependencies.authRequestManager, firestoreManager: dependencies.firestoreManager)
        let presenter = LoginPresenter()
        let interactor = LoginInteractor(worker: worker, presenter: presenter)
        let view = LoginViewController(interactor: interactor, router: router)
        presenter.viewController = view
        router.viewController = view
        return UINavigationController(rootViewController: view)
    }
        
    func routeToRoot() {
        let navigation = viewController?.navigationController
        let destinationVC = RootViewController()
        navigation?.pushViewController(destinationVC, animated: true)
        navigation?.dismiss(animated: false)
    }

    func routeToPassReset() {
        let navigation = viewController?.navigationController
        let destinationVC = PasswordResetRouter.assemble(dependencies: FirebaseAuthServices())
        navigation?.pushViewController(destinationVC, animated: true)
    }
    
    func routeToRegister() {
        let navigation = viewController?.navigationController
        let destinationVC = RegisterRouter.assemble(fbAuth: FirebaseAuthServices(), firestore: FirebaseFirestoreServices())
        navigation?.pushViewController(destinationVC, animated: true)
    }
    
}
