//
//  LoginWorker.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

// Worker abstraction
protocol LoginWorkerProtocol {
    func login(
        request: LoginBusinessModel.Login.Request,
        success: @escaping (_ model: SessionResponse) -> Void,
        failure: @escaping (_ error: Error) -> Void
    )
}

// Class that executes the services and converts data
class LoginWorker: LoginWorkerProtocol {
    
    let authRequestManager: FirebaseAuthManager
    let firestoreManager: FirebaseFirestoreManager
    
    init(authRequestManager: FirebaseAuthManager, firestoreManager: FirebaseFirestoreManager) {
        self.authRequestManager = authRequestManager
        self.firestoreManager = firestoreManager
    }
    
    func login(request: LoginBusinessModel.Login.Request, success: @escaping (SessionResponse) -> Void, failure: @escaping (Error) -> Void) {
        authRequestManager.signIn(
            email: request.username,
            password: request.password
        ){ [weak self] authRequest, error in
            if error != nil {
                failure(error!)
                return
            }
            let authUser = authRequest?.user
            let userData = ["uid": authUser!.uid,
                            "email": authUser?.email ?? "N/A",
                            "photoUrl": ""]
            self?.saveUser(user: userData, document: authUser!.uid)
            DispatchQueue.main.async {
                let response = SessionResponse(username: authUser?.email ?? "N/A")
                success(response)
            }
        }
    }
    
    func saveUser(user: [String : Any], document: String){
        //firestoreManager.postDataWithDoc(collection: "Users", document: document, data: user){ success in
            //if(success){
                //print("Saved user: \(user)")
            //}
        //}
    }
    
    
}
