//
//  MyEventsInteractor.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

protocol MyEventsInteractorProcotol {
    func updateEventsActivities(request: MyEventsBusinessModel.UpdateEvent.Request)
    func searchEvents(query: String)
    func getEvents()
}
class MyEventsInteractor: MyEventsInteractorProcotol {
    
    let worker: MyEventsWorkerProtocol
    let presenter: MyEventsPresenterProtocol & MyEventsPresentAlertsProtocol
    
    init(worker: MyEventsWorkerProtocol, presenter: MyEventsPresenterProtocol & MyEventsPresentAlertsProtocol){
        self.worker = worker
        self.presenter = presenter
    }
    
    func updateEventsActivities(request: MyEventsBusinessModel.UpdateEvent.Request) {
        //Presenter show loading
        presenter.presentLoading()
        worker.updateAttendeesCount(
            uid: request.uid,
            city: request.city,
            isCreator: request.isCreator){ [weak self] didUpdate in
            //Tell presenter to stop loading
            if(didUpdate){
                //Show success text
                let text = "Se han actualizado correctamente sus eventos."
                //Tell presenter to show alert dialog
                self?.presenter.presentError(text: text)
            }else{
                //Show falure text
                let text = "Lo sentimos, ha ocurrido un problema al actualizar sus eventos."
                //Tell presenter to show alert dialog
                self?.presenter.presentError(text: text)
            }
            
        }
    }
    
    func searchEvents(query: String){
        //tell Presenter show loading
        presenter.presentLoading()
        worker.searchEvents(
            query: query,
            success: { [weak self] dataList in
                //tell Presenter to stop loading
                self?.presenter.removeLoading()
                //pass data to presenter
                self?.presenter.presentLoadEvents(response: .init(items: dataList))
            }, failure: { [weak self] error in
                //tell Presenter to stop loading
                self?.presenter.removeLoading()
                self?.presenter.presentError(text: "Ha ocurrido un problema al cargar los datos.")
            }
        )
    }
    func getEvents(){
        //tell Presenter show loading
        presenter.presentLoading()
        worker.getEvents(success: { [weak self] dataList in
                //tell Presenter to stop loading
                self?.presenter.removeLoading()
                //Pass data to presenter
                self?.presenter.presentLoadEvents(response: .init(items: dataList))
            }, failure: { [weak self] error in
                //tell Presenter to stop loading
                self?.presenter.removeLoading()
                //tell presenter to show error alert
                self?.presenter.presentError(text: "Ha ocurrido un problema al cargar los datos.")
            }
        )
        
    }
    
    
}
