//
//  MyEventsPresenter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import UIKit

//These Protocols are abstractions of presenter and are used by the interactor
//This protocol contains functions to load data and route to other scenes
protocol MyEventsPresenterProtocol {
    func presentLoadEvents(response: MyEventsBusinessModel.LoadData.EventsResponse)
}
//This protocol has functions to present, hide activity indicator and present error dialog
protocol MyEventsPresentAlertsProtocol{
    func presentLoading()
    func removeLoading()
    func presentError(text: String)
}

//The presenter will transform the information into the viewmodel and pass it to the viewcontroller
//Also will be in charge of caching images
class MyEventsPresenter: MyEventsPresenterProtocol, MyEventsPresentAlertsProtocol {

    //Viewcontroller reference
    weak var viewController: (
        MyEventsViewControllerProtocol &
        MyEventsViewControllerAlertsProtocol
    )?
    
    //This function will get the places data from interactor
    //Will convert it to the viewmodel
    //Will pass it to the viewController
    func presentLoadEvents(response: MyEventsBusinessModel.LoadData.EventsResponse) {
        viewController?.displayLoadData(
            viewModel: .init(
                items: response.items.map { eventsModelToViewModel($0) }
            )
        )
    }

    //Convert activities models to item viewmodel
    func eventsModelToViewModel(_ model: UserEvent) -> MyEventsBusinessModel.LoadData.ItemViewModel {
        .init(
            title1: model.eventName,
            text1: model.date,
            text2: model.placeName,
            uid: model.activityUid,
            city: model.city,
            isCreator: model.isCreator,
            image: "",
            loadImage: { imageView in
                imageView.image = UIImage(named: "QuillairRunner.png")
            }
        )
    }
    
    func presentLoading() {
        viewController?.displayLoading()
    }
    func removeLoading() {
        viewController?.hideLoading()
    }
    func presentError(text: String) {
        viewController?.displayError(text: text)
    }
    
    
}
