//
//  MyProfileInteractor.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import Foundation

protocol MyProfileInteractorProtocol {
    func updateUserTags(request: MyProfileBusinessModel.UpdateUserTags.Request)
    func updateUserImage(request: MyProfileBusinessModel.UpdateUserImage.Request)
    func logout()
    func getUserData()
    func viewDidLoad()
}
class MyProfileInteractor: MyProfileInteractorProtocol {
    
    let worker: MyProfileWorkerProtocol
    let presenter: MyProfilePresenterProtocol
    
    init(worker: MyProfileWorkerProtocol, presenter: MyProfilePresenterProtocol){
        self.worker = worker
        self.presenter = presenter
    }

    func viewDidLoad() {
        //Tell presenter to setup view style
        presenter.presentSetupView()
    }
    
    func updateUserTags(request: MyProfileBusinessModel.UpdateUserTags.Request) {
        //Tell presenter to show loading
        presenter.presentLoading()
        worker.updateUserTags(tags: request.tags){ [weak self] didUpdate in
            //Tell presenter to hide loading
            self?.presenter.removeLoading()
            var text = "Se han actualizado su usuario exitosamente."
            if(!didUpdate){
                text = "Ha ocurrido un error actualizando sus datos."
            }
            //Tell presenter to pass this text to the view
            self?.presenter.presentResponse(text: text)
        }
    }
    
    func updateUserImage(request: MyProfileBusinessModel.UpdateUserImage.Request) {
        //Tell presenter to show loading
        presenter.presentLoading()
        worker.updateUserImage(path: request.path){ [weak self] didUpdate in
            //Tell presenter to hide loading
            self?.presenter.removeLoading()
            var text = "Se han actualizado su usuario exitosamente."
            if(!didUpdate){
                text = "Ha ocurrido un error actualizando sus datos."
            }
            //Tell presenter to pass this text to the view
            self?.presenter.presentResponse(text: text)
        }
    }
    
    func getUserData() {
        presenter.presentLoading()
        //Tell presenter to show loading
        worker.getUserFromDb(){ [weak self]  user, error in
            //Tell presenter to hide loading
            self?.presenter.removeLoading()
            if error != nil {
                //Tell presenter to show error dialog
                self?.presenter.presentResponse(text: "No se han podido cargar los datos del usuario.")
            }else if user != nil {
                //Pass user to the presenter
                self?.presenter.presentUserData(response: .init(user: user!))
            }
                
        }
    }
    
    func logout() {
        let didLogout = worker.logout()
        if(didLogout){
            //Tell presenter to go to root
            presenter.presentRouteToRoot()
        }
    }

    
    
    
    
}
