//
//  MyProfilePresenter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import UIKit

protocol MyProfilePresenterProtocol {
    func presentUserData(response: MyProfileBusinessModel.FetchUser.Response)
    func presentSetupView()
    func presentLoading()
    func removeLoading()
    func presentResponse(text: String)
    func presentWarning(text: String)
    func presentRouteToRoot()
}

class MyProfilePresenter: MyProfilePresenterProtocol {
    
    weak var viewController: (
        MyProfileViewControllerProtocol &
        MyProfileViewLoadingProtocol
    )?
    
    let imageCache: ImageCacheManager
    init(imageCache: ImageCacheManager){
        self.imageCache = imageCache
    }
    
    func presentUserData(response: MyProfileBusinessModel.FetchUser.Response) {
        let data = response.user
        viewController?.displayData(
            viewModel: .init(
                image: data.photoUrl,
                loadImage: { [weak self] imageView in
                    self?.imageCache.getImage(data.photoUrl){ image in
                        imageView.image = image
                    }
                },
                email: data.email,
                tags: data.interests
            )
        )
    }
    
    func presentSetupView() {
        viewController?.displaySetupView(
            viewModel: .init(
                grayButton: .init(
                    cornerRadius: 5,
                    borderWidth: 1,
                    borderColor: UIColor.systemGray3.cgColor),
                greenButton: .init(
                    cornerRadius: 5,
                    borderWidth: 1,
                    borderColor: UIColor.systemGreen.cgColor)
            )
        )
    }
    
    func presentLoading() {
        viewController?.displayLoading()
    }
    
    func removeLoading() {
        viewController?.hideLoading()
    }
    
    func presentResponse(text: String) {
        viewController?.displayResultAlert(text: text)
    }
    
    func presentWarning(text: String) {
        viewController?.displayWarningAlert(text: text)
    }
    
    func presentRouteToRoot() {
        viewController?.displayRouteToRoot()
    }
    
    
}
