//
//  MyProfileRouter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import UIKit

protocol MyProfileRouterProtocol {
    func routeToRoot()
}

class MyProfileRouter: MyProfileRouterProtocol {

    weak var viewController: UIViewController?

    static func assemble(dependencies:
                            HasAuthRequestManager &
                            HasFirestoreManager &
                            HasFirebaseImageUpload &
                            HasImageCacheManager) -> UIViewController {
        let router = MyProfileRouter()
        let worker = MyProfileWorker(
            firestore: dependencies.firestoreManager,
            imageUpload: dependencies.firebaseImageUpload,
            auth: dependencies.authRequestManager)
        let presenter = MyProfilePresenter(imageCache: dependencies.imageCacheManager)
        let interactor = MyProfileInteractor(worker: worker, presenter: presenter)
        let view = MyProfileViewController(interactor: interactor, router: router)
        presenter.viewController = view
        router.viewController = view
        let nav = UINavigationController(rootViewController: view)
        return nav
    }
    
    func routeToRoot() {
        let navigation = viewController?.navigationController
        let destinationVC = RootViewController()
        navigation?.pushViewController(destinationVC, animated: true)
        navigation?.dismiss(animated: false)
    }
    

}

