//
//  MyProfileWorker.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import UIKit

protocol MyProfileWorkerProtocol {
    func updateUserTags(tags: String, completion: @escaping (_ didUpdate: Bool)->Void)
    func updateUserImage(
        path: URL,
        completion: @escaping (_ didUpdate: Bool)-> Void)
    func getUserFromDb(
        completion: @escaping (_ userData: UserData?, _ error: Error?)->Void)
    func logout()->Bool
}
class MyProfileWorker: MyProfileWorkerProtocol {
    
    let firestore: FirebaseFirestoreManager
    let imageUpload: FirebaseImageUploadManager
    let auth: FirebaseAuthManager
    
    init(firestore: FirebaseFirestoreManager,
         imageUpload: FirebaseImageUploadManager,
         auth: FirebaseAuthManager){
        self.firestore = firestore
        self.imageUpload = imageUpload
        self.auth = auth
    }
    
    //Update user tags
    func updateUserTags(tags: String, completion: @escaping (Bool) -> Void) {
        //Get user id
        let userUID = auth.getUser()!.uid as String
        let d: [String: Any] = [
            "interests":tags
        ]
        //Update document
        firestore.updateWithId(
            collection: "Users",
            document: userUID,
            data: d){ didUpdate in
            completion(didUpdate)
        }
    }
    
    //Will save image in the storage
    //Then will update image reference for the user
    func updateUserImage(path: URL, completion: @escaping (Bool) -> Void) {
        let userUID = auth.getUser()!.uid as String
        imageUpload.uploadImage(
            path: path,
            name: userUID){[weak self] url, error in
            if error != nil{
                completion(false)
            }else if url != nil {
                let d: [String: Any] = [
                    "photoUrl": url!
                ]
                self?.firestore.updateWithId(
                    collection: "Users",
                    document: userUID,
                    data: d){ didUpdate in
                    completion(didUpdate)
                }
            }
        }
    }
    
    func getUserFromDb(completion: @escaping (UserData?, Error?) -> Void) {
        let userUID = auth.getUser()!.uid as String
        firestore.fetchDocument(
            mainCollection: "Users",
            document: userUID){ doc, error in
            
            if let error = error {
                completion(nil, error)
                return
            }
            
            let docData = doc!.data()
            let user = UserData(
                uid: docData!["uid"] as! String,
                email: docData!["email"] as! String,
                photoUrl: docData!["photoUrl"] as! String,
                interests: docData!["interests"] as! String
            )
            completion(user, nil)
        }
    }
    
    func logout()->Bool{
        return auth.signOut()
    }
    
}
