//
//  NewEventInteractor.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import Foundation

//Interactor abstraction
//Used by the viewController
//Uses business models to represent data
protocol NewEventInteractorProtocol {
    func saveActivity(request: NewEventBusinessModel.SaveEvent.Request)
    func viewDidLoad()
    func loadData()
}

//Datastore protocol receives data from other scenes routers
protocol NewEventDataStore: AnyObject {
    var place: Place? { get set }
}

class NewEventInteractor: NewEventInteractorProtocol, NewEventDataStore {
    
    var place: Place?
    
    let worker: NewEventWorkerProtocol
    let presenter: NewEventPresenterProtocol
    
    init(worker: NewEventWorkerProtocol, presenter: NewEventPresenterProtocol){
        self.worker = worker
        self.presenter = presenter
    }
    
    func viewDidLoad(){
        //Tell presenter to set styles
        presenter.presentSetupView()
        print("load view")
    }
    
    //Pass the place data to the presenter
    func loadData() {
        if let placeValue = place {
            presenter.presentPlaceData(response: .init(place: placeValue))
            print("got data")
        }
    }
    
    //tells the worker to save data
    func saveActivity(request: NewEventBusinessModel.SaveEvent.Request) {
        //tell presenter to show loader
        presenter.presentLoading()
        //Call worker
        let pos = Location(latitude: place!.lat, longitude: place!.lng)
        worker.saveActivity(
            name: request.eventName,
            description: request.description,
            tags: request.tags,
            dateTime: request.dateTime,
            position: pos,
            placeName: place!.name,
            placeUid: place!.uid){ [weak self] didSave in
            
            //Tell presenter to hide loader
            self?.presenter.removeLoading()
            //Tell presenter to show dialog with text
            if(didSave){
                let text = "Su evento se ha guardado exitosamente. Otros usuarios lo encontrarán en la pestaña de Actividades. Para editar tu asistencia al evento puedes ingresar a la pestaña de Mis eventos."
                self?.presenter.presentResultAlert(text: text)
            }else{
                let text = "Ha ocurrido un error al guardar este evento. Intente nuevamente."
                self?.presenter.presentResultAlert(text: text)
            }
            
        }
    }
    
    
    
}
