//
//  NewEventPresenter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import UIKit

protocol NewEventPresenterProtocol {
    func presentLoading()
    func removeLoading()
    func presentSetupView()
    func presentResultAlert(text: String)
    func presentPlaceData(response: NewEventBusinessModel.LoadData.PlaceResponse)
}
class NewEventPresenter: NewEventPresenterProtocol {
    
    weak var viewController: (
        NewEventViewControllerProtocol &
        NewEventViewLoadingProtocol
    )?
    
    func presentLoading(){
        viewController?.displayLoading()
    }
    func removeLoading(){
        viewController?.hideLoading()
    }
    func presentSetupView(){
        viewController?.displaySetupView(
            viewModel: .init(
                button: .init(cornerRadius: 5, borderWidth: 1, borderColor: UIColor.systemGreen.cgColor),
                validator: { name, desc, tags in
                    let nameValue = name ?? ""
                    let descValue = desc ?? ""
                    let tagsValue = tags ?? ""
                    var isValid = true
                    var errorMessage = ""
                    if nameValue.isEmpty{
                        errorMessage = "Introduzca el nombre del evento"
                        isValid = false
                    }else if descValue.isEmpty{
                        errorMessage = "Introduzca la descripción del evento"
                        isValid = false
                    }else if tagsValue.isEmpty{
                        errorMessage = "Introduzca las etiquetas del evento"
                        isValid = false
                    }
                    return .init(
                        errorMessage: errorMessage,
                        isValid: isValid,
                        eventNameValue: nameValue,
                        descriptionValue: descValue,
                        tagsValue: tagsValue)
                }
            )
        )
    }
    
    func presentPlaceData(response: NewEventBusinessModel.LoadData.PlaceResponse){
        let data = response.place
        let pos = Location(latitude: data.lat, longitude: data.lng)
        viewController?.displayData(
            viewModel: .init(placeName: data.name, position: pos)
        )
    }
    
    func presentResultAlert(text: String){
        viewController?.displayResultAlert(text: text)
    }
    
}
