//
//  NewEventRouter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 1/12/21.
//

import UIKit

//Router abstraction
//The router is used by the viewController to go to other scenes
protocol NewEventRouterProtocol {
    var dataStore: NewEventDataStore? { get set }
    func routeToRoot()
}
//This class will also initialize the viewController
//Will pass the dependencies
class NewEventRouter: NewEventRouterProtocol {
    
    var dataStore: NewEventDataStore?
    weak var viewController: UIViewController?
    
    static func assemble(
        firestore: FirebaseFirestoreManager,
        auth: FirebaseAuthManager,
        location: LocationManager) -> NewEventViewController {
            let router = NewEventRouter()
            let presenter = NewEventPresenter()
            let worker = NewEventWorker(
                firestore: firestore,
                auth: auth,
                location: location)
            let interactor = NewEventInteractor(worker: worker, presenter: presenter)
            let view = NewEventViewController(interactor: interactor, router: router)
            presenter.viewController = view
            router.viewController = view
            router.dataStore = interactor
            return view
    }
    
    //Will route to root so the user lands in the homeView
    func routeToRoot() {
        let navigation = viewController?.navigationController
        let destinationVC = RootViewController()
        navigation?.pushViewController(destinationVC, animated: true)
        navigation?.dismiss(animated: false)
    }
    
}
