//
//  NewEventWorker.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

//Abstraction fro worker
//Will be used by the interactor
protocol NewEventWorkerProtocol {
    func saveActivity(
        name: String,
        description: String,
        tags: String,
        dateTime: String,
        position: Location,
        placeName: String,
        placeUid: String,
        completion: @escaping (Bool) -> Void)
}

class NewEventWorker: NewEventWorkerProtocol {
    
    let firestore: FirebaseFirestoreManager
    let auth: FirebaseAuthManager
    let location: LocationManager
    
    init(firestore: FirebaseFirestoreManager, auth: FirebaseAuthManager, location: LocationManager){
        self.firestore = firestore
        self.auth = auth
        self.location = location
    }
    
    //Will add the event related to the activity to the user collection
    func addToUserEvents(
        activityUid: String,
        date: String,
        isCreator: Bool,
        isGoing: Bool,
        name: String,
        whereName: String,
        userUid: String,
        city: String,
        completion: @escaping (_ didSave: Bool)->Void){
        
        let userUID = auth.getUser()!.uid as String
        
        let d:[String:Any] = [
            "activityUid": activityUid,
            "date": date,
            "isCreator": true,
            "isGoing": true,
            "name": name,
            "where": whereName,
            "city": city,
        ]
        
        firestore.postDataDeeperWithUID(
            mainCollection: "Users",
            mainDocument: userUID,
            secondaryCollection: "Events",
            documentUID: activityUid,
            data: d){ didSave in
            completion(true)
        }
    }
    
    //Function to save activity into db
    //Then will call addToUserEvents and save the event to the user
    func saveActivity(
        name: String,
        description: String,
        tags: String,
        dateTime: String,
        position: Location,
        placeName: String,
        placeUid: String,
        completion: @escaping (Bool) -> Void) {

        let userUID = auth.getUser()!.uid as String
        
        //to save place first needs to check city
        location.getCityFromLocation(location: position){ [weak self] city in
            if let city = city {
                //Send data to firestore
                let data: [String: Any] = [
                    "attendees":1,
                    "attendeesIDs": [userUID],
                    "creator": userUID,
                    "dateTime": dateTime,
                    "description":description,
                    "isPublic": true,
                    "lat": position.latitude,
                    "lng": position.longitude,
                    "name": name,
                    "placeName": placeName,
                    "placeUid": placeUid,
                    "tags": tags
                ]
                
                self?.firestore.postDataDeeper(
                    mainCollection: "Cities",
                    document: city,
                    secondaryCollection: "Activities",
                    data: data){ [weak self] didSaveAct, ref in
                    
                    if(didSaveAct){
                        self?.addToUserEvents(
                            activityUid: ref,
                            date: dateTime,
                            isCreator: true,
                            isGoing: true,
                            name: name,
                            whereName: placeName,
                            userUid: userUID,
                            city: city){ didSaveEvent in
                                completion(didSaveEvent)
                        }
                    }else{
                        completion(false)
                    }
                }
            }else{
                completion(false)
            }
        }
    }

}

