//
//  PasswordResetInteractor.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

// Interactor abstraction
protocol PasswordResetInteractorProtocol {
    func viewDidLoad()
    func resetPassword(request: PasswordResetBusinessModel.PasswordReset.Request)
}

// Class that sends transformed data to the presenter
class PasswordResetInteractor: PasswordResetInteractorProtocol {
    
    let worker: PasswordResetWorkerProtocol
    let presenter: PasswordResetPresenterProtocol
    
    init(worker: PasswordResetWorkerProtocol, presenter: PasswordResetPresenterProtocol) {
        self.worker = worker
        self.presenter = presenter
    }
    
    func viewDidLoad() {
        presenter.presentSetupView()
    }
    
    func resetPassword(request: PasswordResetBusinessModel.PasswordReset.Request) {
        presenter.presentLoading()
        self.worker.resetPassword(request: request) { [weak self] responseText in
            print("LOGIN INTERACTOR RESPONSE \(responseText)")
            self?.presenter.removeLoading()
            self?.presenter.presentResultAlert(text: responseText)
        }

    }
    
}
