//
//  PasswordResetPresenter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

// Presenter abstraction
protocol PasswordResetPresenterProtocol{
    func presentRouteToLogin()
    func presentLoading()
    func removeLoading()
    func presentSetupView()
    func presentResultAlert(text: String)
}

// Presenter for login. Will tell the view what to show.
class PasswordResetPresenter: PasswordResetPresenterProtocol {
    
    weak var viewController: (
        PasswordResetViewRouteProtocol &
        PasswordResetViewLoadingProtocol
    )?
    
    func presentRouteToLogin() {
        viewController?.displayRouteToLogin()
    }
    
    func presentLoading() {
        viewController?.displayLoading()
    }
    
    func removeLoading() {
        viewController?.hideLoading()
    }
    
    //Setup view styling and validators
    func presentSetupView() {
        viewController?.displaySetupView(
            viewModel: .init(
                resetPass: .init(cornerRadius: 5, borderWidth: 1, borderColor: UIColor.systemGreen.cgColor),
                validator: { username in
                    let usernameValue = username ?? ""
                    var isValid = true
                    var errorMessage = ""
                    if usernameValue.isEmpty{
                        errorMessage = "Introduzca su usuario"
                        isValid = false
                    }
                    return .init(errorMessage: errorMessage, isValid: isValid, usernameValue: usernameValue)
                },
                username: .init(placeholder: "Usuario")
            )
        )
    }
    
    func presentResultAlert(text: String){
        viewController?.displayResultAlert(text: text)
    }
    
}

