//
//  PasswordResetViewController.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

//Protocol to route back to root
protocol PasswordResetViewRouteProtocol: AnyObject {
    func displayRouteToLogin()
    func displaySetupView(viewModel: PasswordResetBusinessModel.SetupView.ViewModel)
    func displayResultAlert(text: String)
}

//Protocol to display loading
protocol PasswordResetViewLoadingProtocol: AnyObject {
    func displayLoading()
    func hideLoading()
}

class PasswordResetViewController: UIViewController, PasswordResetViewRouteProtocol, PasswordResetViewLoadingProtocol {
    
    //View elements
    @IBOutlet weak var userInput: UITextField!
    @IBOutlet weak var validationText: UILabel!
    @IBOutlet weak var recoveryBtn: UIButton!
    @IBOutlet weak var loader: UIActivityIndicatorView!
    @IBOutlet weak var goLoginBtn: UIButton!
    
    var viewModel: PasswordResetBusinessModel.SetupView.ViewModel?
    
    let interactor: PasswordResetInteractorProtocol
    let router: PasswordResetRouterProtocol
    
    init(interactor: PasswordResetInteractorProtocol, router: PasswordResetRouterProtocol) {
        self.interactor = interactor
        self.router = router
        let bundle = Bundle(for: PasswordResetViewController.self)
        super.init(nibName: "\(PasswordResetViewController.self)", bundle: bundle)
    }
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        interactor.viewDidLoad()
    }
    
    @IBAction func recoveryClick(_ sender: Any) {
        interactor.resetPassword(request: PasswordResetBusinessModel.PasswordReset.Request(username: userInput.text ?? ""))
    }
    @IBAction func goLoginClick(_ sender: Any) {
        displayRouteToLogin()
    }
    
    func displayRouteToLogin() {
        router.routeToLogin()
    }
    
    func displaySetupView(viewModel: PasswordResetBusinessModel.SetupView.ViewModel) {
        self.viewModel = viewModel
        recoveryBtn.layer.cornerRadius = viewModel.resetPass.cornerRadius
        recoveryBtn.layer.borderWidth = viewModel.resetPass.borderWidth
        recoveryBtn.layer.borderColor = viewModel.resetPass.borderColor
        self.navigationController?.setNavigationBarHidden(true, animated: false)
        //Looks for single or multiple taps.
        let tap = UITapGestureRecognizer(
            target: self,
            action: #selector(UIInputViewController.dismissKeyboard)
        )
        view.addGestureRecognizer(tap)
    }
    
    //Calls this function when the tap is recognized.
    @objc func dismissKeyboard() {
        //Causes the view (or one of its embedded text fields) to resign the first responder status.
        view.endEditing(true)
    }
    
    func displayLoading() {
        loader.isHidden = false
        recoveryBtn.isHidden = true
        validationText.isHidden = true
        goLoginBtn.isHidden = true
    }
    
    func hideLoading() {
        loader.isHidden = true
        recoveryBtn.isHidden = false
        goLoginBtn.isHidden = false
    }
    
    func displayResultAlert(text: String) {
        let alert = UIAlertController(title: "Aviso", message: text, preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "Entendido", style: .default, handler: { [weak self] action in
            self?.displayRouteToLogin()
        }))
        self.present(alert, animated: true, completion: nil)
    }
    
}


