//
//  PasswordResetWorker.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

// Worker abstraction
protocol PasswordResetWorkerProtocol {
    func resetPassword(
        request: PasswordResetBusinessModel.PasswordReset.Request,
        completion: @escaping (_ completionText: String) -> Void
    )
}

// Class that executes the services and converts data
class PasswordResetWorker: PasswordResetWorkerProtocol {
    
    let authRequestManager: FirebaseAuthManager
    
    init(authRequestManager: FirebaseAuthManager) {
        self.authRequestManager = authRequestManager
    }
    
    func resetPassword(request: PasswordResetBusinessModel.PasswordReset.Request, completion: @escaping (String) -> Void) {
        authRequestManager.recoverPassword(
            email: request.username
        ){ isSuccessful in
            var completionText = "Hemos recibido tu petición de cambio de contraseña. Si tu correo electronico es correcto recibirás un mensaje."
            if !isSuccessful {
                completionText = "Lo sentimos, ha ocurrido un problema con la petición."
            }
            DispatchQueue.main.async {
                completion(completionText)
            }
        }
    }
    
    
}
