//
//  RegisterInteractor.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation

// Interactor abstraction
protocol RegisterInteractorProtocol {
    func viewDidLoad()
    func register(request: RegisterBusinessModel.Register.Request)
}

// Class that sends transformed data to the presenter
class RegisterInteractor: RegisterInteractorProtocol {
    
    let worker: RegisterWorkerProtocol
    let presenter: RegisterPresenterProtocol
    
    init(worker: RegisterWorkerProtocol, presenter: RegisterPresenterProtocol) {
        self.worker = worker
        self.presenter = presenter
    }
    
    func viewDidLoad() {
        presenter.presentSetupView()
    }
    
    func register(request: RegisterBusinessModel.Register.Request) {
        presenter.presentLoading()
        self.worker.register(request: request) { [weak self] sessionResponse in
            print("REGISTER INTERACTOR RESPONSE \(sessionResponse.username)")
            self?.presenter.removeLoading()
            self?.presenter.presentRouteToPermissions()
        } failure: { [weak self] error in
            print("LOGIN INTERACTOR ERROR \(error)")
            self?.presenter.removeLoading()
            self?.presenter.presentError(text: "Error en el registro. Por favor intente nuevamente.")
        }

    }
    
}
