//
//  RegisterPresenter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

// Presenter abstraction
protocol RegisterPresenterProtocol{
    func presentRouteToPermissions()
    func presentLoading()
    func removeLoading()
    func presentSetupView()
    func presentError(text: String)
}

// Presenter for login. Will tell the view what to show.
class RegisterPresenter: RegisterPresenterProtocol {
    
    weak var viewController: (
        RegisterViewControllerRouteProtocol & RegisterViewControllerLoadingProtocol
    )?
    
    func presentRouteToPermissions() {
        viewController?.displayRouteToPermissions()
    }
    
    func presentLoading() {
        viewController?.displayLoading()
    }
    
    func removeLoading() {
        viewController?.hideLoading()
    }
    
    func presentError(text: String){
        viewController?.displayError(text: text)
    }
    
    func presentSetupView() {
        viewController?.displaySetupView(
            viewModel: .init(
                register: .init(cornerRadius: 5, borderWidth: 1, borderColor: UIColor.systemGreen.cgColor),
                validator: { username, password, confirmPass in
                    let usernameValue = username ?? ""
                    let passwordValue = password ?? ""
                    let confirmPassValue = confirmPass ?? ""
                    var isValid = true
                    var errorMessage = ""
                    if usernameValue.isEmpty{
                        errorMessage = "Introduzca su usuario"
                        isValid = false
                    }else if passwordValue.isEmpty{
                        errorMessage = "Introduzca su contraseña"
                        isValid = false
                    }else if confirmPassValue.isEmpty{
                        errorMessage = "Confirme su contraseña"
                        isValid = false
                    }else if passwordValue != confirmPassValue{
                        errorMessage = "Las contraseñas no coinciden"
                        isValid = false
                    }
                    return .init(errorMessage: errorMessage, isValid: isValid, usernameValue: usernameValue, passwordValue: passwordValue, confirmPassValue: confirmPassValue)
                },
                username: .init(placeholder: "Correo electrónico"),
                password: .init(placeholder: "Contraseña"),
                confirmPass: .init(placeholder: "Confirmar contraseña"))
        )
    }
    
}

