//
//  RegisterRouter.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

//Router abstraction
protocol RegisterRouterProtocol {
    func routeToLogin()
    func routeToPermissions()
}

class RegisterRouter: RegisterRouterProtocol {

    weak var viewController: UIViewController?

    static func assemble(fbAuth: FirebaseAuthManager & FBObserverManager, firestore: FirebaseFirestoreManager) -> RegisterViewController {
        let router = RegisterRouter()
        let worker = RegisterWorker(authRequestManager: fbAuth, firestoreManager: firestore)
        let presenter = RegisterPresenter()
        let interactor = RegisterInteractor(worker: worker, presenter: presenter)
        let view = RegisterViewController(interactor: interactor, router: router)
        presenter.viewController = view
        router.viewController = view
        return view
    }
        
    func routeToLogin() {
        let navigation = viewController?.navigationController
        navigation?.dismiss(animated: false)
    }
    
    func routeToPermissions() {
        let navigation = viewController?.navigationController
        let destinationVC = PermissionsRouter.assemble(dependencies: CoreLocationServices())
        navigation?.pushViewController(destinationVC, animated: true)
    }
    
}
