
import UIKit

//This controller will route first time to login or home if theres an user already
class RootViewController: UIViewController {
    
    //Reference of the dependency factory
    let dependencies = Dependencies.init()
    
    //references for the viewcontrollers of the tabs
    var homeTabVC: UIViewController!
    var myEventsTabVC: UIViewController!
    var myProfileTabVC: UIViewController!
    
    override func viewWillAppear(_ animated: Bool) {
        // this is to test firebase listener
        dependencies.authRequestManager.attachListener(){ auth, user in
            print("AUTH: \(String(describing: auth)) - USER: \(String(describing: user))")
        }
        //Check if user is in
        if dependencies.authRequestManager.getUser() != nil {
            //user is signed in
            goTabs()
            //goLogin()
        } else {
            // No user is signed in.
            goLogin()
        }
        super.viewWillAppear(animated)
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        // Remember to remove listener
        dependencies.authRequestManager.detatchListener()
    }
    
    //Function that shows login
    func goLogin(){
        let destination = LoginRouter.assemble(dependencies: dependencies)
        destination.modalPresentationStyle = .fullScreen
        destination.modalTransitionStyle = .crossDissolve
        DispatchQueue.main.async {
            self.present(destination, animated: true)
        }
    }
    
    func goHome(){
        let destination = HomeRouter.assemble(dependencies: dependencies)
        destination.modalPresentationStyle = .fullScreen
        destination.modalTransitionStyle = .crossDissolve
        DispatchQueue.main.async {
            self.present(destination, animated: true)
        }
    }
    
    //Function to set tabs for home
    func goTabs(){
        
        //setting the initial screen bounds of the view
        self.homeTabVC = HomeRouter.assemble(dependencies: dependencies)
        self.myEventsTabVC = MyEventsRouter.assemble(dependencies: dependencies)
        self.myProfileTabVC = MyProfileRouter.assemble(dependencies: dependencies)
        
        //creating object of TabViewController[1,2,3] class
        let tabBarController = UITabBarController()
        
        //creating object of UITabBarController class
        tabBarController.viewControllers = [homeTabVC!, myEventsTabVC!, myProfileTabVC!]
        
        //adding all three views to the TabBarView
        let explore = UITabBarItem(
            title: "Explorar",
            image: UIImage(systemName: "globe"),
            tag: 0)
        let myEvents = UITabBarItem(
            title: "Mis Eventos",
            image: UIImage(systemName: "person.3"),
            tag: 1)
        let myProfile = UITabBarItem(
            title: "Mi Perfil",
            image: UIImage(systemName: "person"),
            tag: 2)
        
        //defining the items of the TabBar corresponding to three views
        homeTabVC?.tabBarItem = explore
        myEventsTabVC?.tabBarItem = myEvents
        myProfileTabVC?.tabBarItem = myProfile
        
        //setting TabBarItems corresponding to each view in TabBarController
        //setting the initial VieController as tabBarController

        let destination = tabBarController
        destination.modalPresentationStyle = .fullScreen
        destination.modalTransitionStyle = .crossDissolve
        DispatchQueue.main.async {
            self.present(destination, animated: true)
        }
        
    }
    
}
