//
//  FirebaseServices.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import Foundation
import Firebase

//This class encapsulates every Firebase use for the app
class FirebaseAuthServices: FirebaseAuthManager, FBObserverManager {

    var handle: NSObjectProtocol? = nil
    var fbAuth = Auth.auth()
    
    //Firebase listeners
    func attachListener(completion: @escaping (Auth?, User?) -> Void) {
        handle = fbAuth.addStateDidChangeListener { auth, user in
          completion(auth, user)
        }
    }
    
    func detatchListener() {
        fbAuth.removeStateDidChangeListener(handle!)
    }
 
    //Authentication functions
    func signIn(email: String, password: String, completion: @escaping (AuthDataResult?, Error?) -> Void) {
        fbAuth.signIn(withEmail: email, password: password) { authResult, error in
          completion(authResult, error)
        }
    }
    
    func signOut()->Bool {
        do {
            try fbAuth.signOut()
            return true
        } catch let signOutError as NSError {
            print("Error signing out: %@", signOutError)
            return false
        }
    }
    
    func getUser() -> User? {
        return fbAuth.currentUser
    }
    
    func signUp(email: String, password: String, completion: @escaping (AuthDataResult?, Error?) -> Void) {
        fbAuth.createUser(withEmail: email, password: password) { authResult, error in
          completion(authResult, error)
        }
    }
    
    func recoverPassword(email: String, completion: @escaping (Bool) -> Void) {
        fbAuth.sendPasswordReset(withEmail: email) { error in
            var isSuccessful = true
            if error != nil {
              isSuccessful = false
            }
            completion(isSuccessful)
        }
    }
    
}
