//
//  FirebaseImageUploadService.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez on 4/12/21.
//

import UIKit
import Firebase

//Class that encapsulates upload services with firebase
//For sending images to firebase storage
class FirebaseImageUploadService: FirebaseImageUploadManager {
    
    let storage = Storage.storage()
    
    func uploadImage(
        path: URL,
        name: String,
        completion: @escaping (_ imageUrl: String?, _ error: Error?)-> Void) {
    
        let fileExtension = path.pathExtension
        let fileName = "\(Date.init())_\(name).\(fileExtension)"
        
        // Create a root reference
        let storageRef = storage.reference()

        // Create a reference to the file you want to upload
        let riversRef = storageRef.child(fileName)

        // Upload the file to the path "images/rivers.jpg"
        riversRef.putFile(from: path, metadata: nil) { metadata, error in
            if let error = error {
                print("Upload error: \(error.localizedDescription)")
                completion(nil, error)
                return
            }
            // You can also access to download URL after upload.
            riversRef.downloadURL { (url, error) in
                guard let downloadURL = url else {
                    // Uh-oh, an error occurred!
                    completion(nil, error)
                    return
                }
                completion(downloadURL.absoluteString, nil)
            }
        }
    }
    
    
}
