//
//  ImageLoadingCachingService.swift
//  Quillair
//
//  Created by Valery Patrizia Madiedo Gomez
//

import UIKit

//Class helper for downloading images
//Uses urlsession for requesting downloads
class ImageLoadingCachingService: ImageCacheManager {
    let cache = URLCache.shared
    let urlSession = URLSession.shared
    let placeholder = UIImage(named: "QuillairRunner.png")
    
    func getImage(_ url: String, completion: @escaping (UIImage?) -> Void) {
        guard let imageUrl = URL(string: url) else {
            completion(placeholder)
            return
        }
        let request = URLRequest(url: imageUrl)
        if let data = cache.cachedResponse(for: request)?.data, let image = UIImage(data: data){
            completion(image)
        } else {
            completion(placeholder)
            urlSession.dataTask(
                with: request,
                completionHandler: { [weak self] data, response, error in
                    if let data = data,
                       let response = response,((response as? HTTPURLResponse)?.statusCode ?? 500) < 300,
                       let image = UIImage(data: data) {
                        let cachedData = CachedURLResponse(response: response, data: data)
                        self?.cache.storeCachedResponse(cachedData, for: request)
                        DispatchQueue.main.async {
                            completion(image)
                        }
                    }
                }
            ).resume()
        }
    }
}

